#!/bin/sh

#  compute-attractors.sh
#  
#	It permits to compute the attractors of an automata network. Each answer is a set of states that constitute an attractor	
#
#  Created by Emna Ben Abdallah on 25/08/2016.
#  Updated on 03/07/2017.
#

# The AN model of which we will compute the attractors
an_model=$1
# The size of the attractor: number of sets in the attractor
size_attractor=$2
# Dynamic semantics: 's' for synchron and 'a' for asynchron
semantic_dynamic=$3
# Display all results '0' or just '1':
nb_results=$4

if [ $size_attractor == 0 ];
then
	echo "The size of the attractor should be greater or equal to 1"
elif [ $size_attractor == 1 ];
then
	echo -e "%----- The attractor computed for $an_model \n %----- The size of the attractor = $size_attractor \n" 
	./clingo scripts/fixed-points.lp $an_model 0 

elif [ $size_attractor > 1 ];
then
	echo -e "%----- The attractor computed for $an_model \n %----- The size of the attractor = $size_attractor " 
	if [ $semantic_dynamic == 's' ];
       	then
		if [ $nb_results == 1 ];
       		then
			echo -e "  %----- The attractor computed with Synchronous Dynamics \n" 
			./clingo scripts/synch.lp scripts/attractors.lp $an_model --const n=$size_attractor  
		elif [ $nb_results == 0 ];
       		then
			echo -e "  %----- The attractor computed with Synchronous Dynamics \n" 
			./clingo scripts/synch.lp scripts/attractors.lp $an_model --const n=$size_attractor  0 
		fi
	elif [ $semantic_dynamic == 'a' ];
	then
		if [ $nb_results == 1 ];
       		then
			echo -e "  %----- The attractor computed with Asynchronous Dynamics \n" 
			./clingo scripts/asynch.lp scripts/attractors.lp $an_model --const n=$size_attractor   
		elif [ $nb_results == 0 ];
       		then
			echo -e "  %----- The attractor computed with Asynchronous Dynamics \n" 
			./clingo scripts/asynch.lp scripts/attractors.lp $an_model --const n=$size_attractor 0
		fi
	fi
fi

